#-----------------------------------------------------------------------------
#                    Earthworm Common Variables
#
#  Define values for the Earthworm Common variables.
#  Values of the variables already set within the shell environment will be
#  overwritten by the declarations contained within this file.
#
#  Variables declared inside this file can be recalled within all .d file using
#  the following syntax:   ${VARIABLE_NAME}
#  The respective values will be expanded within the original .d file.
#  The variable expansion for this file is implemented only from the
#  environment shell, avoiding recursivity.
#
#  An example copy of earthworm_commonvars.d resides in the vX.XX/environment
#  directory of this Earthworm distribution.
#  A copy of earthworm_commonvars.d should be placed in your EW_PARAMS
#  directory.
#
#  Syntax:
#          SetEnvVariable VARIABLE_NAME VARIABLE_VALUE
#          SetEnvVariable VARIABLE_NAME "VARIABLE_VALUE"
#
#  VARIABLE_NAME can contain only characters [A-Za-Z0-9_] and it must start
#  with a nonnumeric character.
#  VARIABLE_VALUE can contain all characters execpt for '}',
#                 use quote when it contains spaces.
#  The maximum length for VARIABLE_NAME and VARIABLE_VALUE is 255 characters.
#
#  Best practice:
#     - Avoid to declare EW_HOME, EW_VERSION, EW_LOG, EW_PARAMS, ...
#
#  Examples:
#
#     1) SetEnvVariable MYDERIVEDVAR "${ENVVARFROMSHELL}/myfile"
#        # Value for ENVVARFROMSHELL will be substituted only if the variable
#        # has been set within the shell environment before launching
#        # the module startstop.
#
#     2) SetEnvVariable MYVAR1 xxxxxxx
#        SetEnvVariable MYVAR2 ${MYVAR1}
#        # MYVAR2 will not expanded with variable  from this file, but only
#        # from the shell environment if MYVAR1 has been set outside from here.
#
#-----------------------------------------------------------------------------

SetEnvVariable EW_HOST hvo-demo.isti.com
SetEnvVariable EW_INST_ID INST_HVO
SetEnvVariable AUTH HV
SetEnvVariable NET HV
SetEnvVariable ESA_NAME HVO

SetEnvVariable IP_ADDR  127.0.0.1
SetEnvVariable WSV_IP   127.0.0.1
SetEnvVariable WSV_PORT 16022

# Note that inside HYPOINVERSE_CONFIG is the name of the STATIONFILE,
# so if you change STATIONFILE here you must open HYPOINVERSE_CONFIG and
# change it in there too, as the HYPOINVERSE_CONFIG doesn't expand variables
SetEnvVariable STATIONFILE ewconfig/chan/hinv_sta.d
SetEnvVariable PICK_STA_FILE ewconfig/chan/pick_sta.d
SetEnvVariable HYPOINVERSE_CONFIG eqk/hypoinverse/hvo2.hyp.2000
SetEnvVariable VELOCITY_MODEL eqk/hvo_velocity.d

SetEnvVariable AQMS_DBNAME "archdb1"
SetEnvVariable AQMS_DBUSER "rtem"
SetEnvVariable AQMS_DBPASS "rtem_pass"
SetEnvVariable AQMS_SS "RT1"
