#ifndef MSEEDFILENAME_H
#define MSEEDFILENAME_H

#include "libmseed2.h"

#define MSEEDFILE_SZ 512
#define FORMAT_BUD 0        // BUD miniSEED format
#define FORMAT_SCP 1        // Seiscomp miniSEED format
#define FORMAT_MSEEDINDEX 2 // mseedindex format

typedef struct _MSDATA {
  int debug;
  char *mseeddir;
  int archiveFormat;
  char mseedfile[MSEEDFILE_SZ];
  int *datasamples;
  double delta;
  double starttime;
  double endtime;
  double samprate;
  MSFileParam *msfp;
  MSRecord *msr;
} MSDATA;

/**
 * Clear the miniSEED data.
 * @param msdata the miniSEED data
 */
void clearMsdata(MSDATA *msdata);

/**
 * Free the miniSEED data.
 * @param msdata the miniSEED data
 */
int freeMsdata(MSDATA *msdata);

/**
 * Get the delta.
 * @param samprate the sample rate
 * @return the delta
 */
double getDelta(double samprate);

/**
 * Initialize the miniSEED data after reading the data.
 * @param msdata the miniSEED data
 */
void initMsdata(MSDATA *msdata);

/**
 * Determines if the end of data.
 * @return true if the end of data, false othewise.
 */
int isEndData(MSDATA *msdata);

/**
 *Get the miniSEED file name.
 *
 *Input:
 * @param mseeddir is the miniSEED directory
 * @param t is the Unix epoch time in seconds
 * @param stat is the station code
 * @param chan is the channel code
 * @param net is the network code
 * @param loc is the location code
 * @param archiveFormat is the archive format (FORMAT_BUD, FORMAT_SCP)
 *
 *Output:
 *@param mseedfile is the miniSEED file
 *@return the miniSEED file name.
 */
char *MseedFileName(char *mseedfile, char *mseeddir, double t, char *stat,
                    char *chan, char *net, char *loc, int archiveFormat);

/**
 * Read the miniSEED data.
 * @param msdata the miniSEED data
 * @return MS_ENDOFFILE if end of file, MS_NOERROR  if no error, non-zero if
 * error.
 */
int readData(MSDATA *msdata);
#endif
