#include "dirops_ew_common.h"
#include "earthworm_defs.h"
#include "earthworm_simple_funcs.h"
#include <stdio.h>
#include <string.h>

/**
 * Open a file and create any parent directories if needed if not reading
 * @param pathname the path name for the file
 * @param mode the mode for opening the file (see fopen)
 * @return the FILE pointer or NULL if erro.
 */
FILE *OpenFile(const char *pathname, const char *mode) {
  char *s;
  char parent[MAX_DIR_LEN];
  int n;
  FILE *fp = fopen(pathname, mode);
  if (fp != NULL) {
    return fp;
  }

  // exit if empty mode or read mode
  if (mode[0] == '\0' || mode[0] == 'r') {
    return fp;
  }

  s = strrchr(pathname, '/');
  // exit if no parent
  if (s == NULL) {
    return fp;
  }

  n = (int)(s - pathname);
  strncpy(parent, pathname, n);
  parent[n] = '\0';
  // exit if parent directory already exists
  if (OpenDir(parent) == 0) {
    return fp;
  }

  // if could not create parent directory
  if (RecursiveCreateDir(parent) != EW_SUCCESS) {
    return fp;
  }

  fp = fopen(pathname, mode);
  return fp;
}
