#include <string.h>
#include "k_readcfg.h"

// close the current configuration file
// data - the configuration data
// return the number of open files
int k_closecfg(READCFG_DATA *data) {
  return k_close();
}

// initialize the configuration data
// data - the configuration data
// commandData - command data or NULL if none
void k_initcfg(READCFG_DATA *data, void *commandData) {
  memset(data, 0, sizeof(READCFG_DATA));
  data->commandData = commandData;
}

// open the configuration file
// data - the configuration data
// filename - the configuration filename
// return 0 if error, otherwise the number of open files
int k_opencfg(READCFG_DATA *data, char *filename) {
  int numOpen = k_open( filename );
  if (numOpen == 0) {
    return 0;
  }
  strcpy( data->filesOpen[numOpen - 1], filename );
  return numOpen;
}

// read the configuration
// data - the configuration data
// filename - the configuration filename
// process - the process command function
// return 0 if no error
int k_readcfg(READCFG_DATA *data, char *filename, processCommandType process) {
  int   result;  // return code from function calls
  // open the main configuration file
  result = k_opencfg(data, filename);
  if ( result == 0 ) {
    logit( "e", "Error opening configuration file '%s'.\n",
             filename );
    return -1;
  } else {
    // continue processing as long as there are open files
    do {
      // continue reading from the current open file
      while ( k_rd( ) ) {
        // retrieve the first token from the current line
        data->token = k_str( );
        if ( data->token == NULL || *data->token == '#' ) {
          // Ignore blank or comment lines
          continue;
        }

        if ( *data->token == '@' ) {
          // open a nested configuration file
          result = k_opencfg(data, &(data->token[1]));
          if ( result == 0 ) {
            logit( "e",
                     "Error opening nested configuration file '%s'.\n",
                     &(data->token[1]) );
            return -1;
          }
          continue;
        }
        if (process != NULL) {
           result = process(data);
           if (result != 0) {
              return -1;
           }
        }
        // check for processing errors
        if ( k_err( ) ) {
          logit( "e",
                 "Error processing '%s' in '%s'.\n", data->token,
                 data->filesOpen[getNumOpen() - 1] );
          return 1;
        }
      }
      // file read ok, close and finish reading other files
    } while (k_closecfg(data) != 0);
  }
  return 0;
}
