from flask import request
from flask_restful import reqparse

import logging
logger = logging.getLogger()

class StrictParser(reqparse.RequestParser):

    def parse_args(self, req=None):
        """Overide reqparse parser in order to fail on unknown argument
        """
        logger.info("Enter StrictParser.parse_args()")
        if req is None:
            req = request

        errors = []

        #for arg in request.args:
            #print("Got arg:%s" % arg)
        # MTH: simple hack to catch unknown args
        #      (since flask_restful is a POS)
        known_args = [arg.name for arg in self.args]
        for arg in request.args:
            if arg not in known_args:
                logger.info("arg:%s ==> Not in known_args!" % arg)
                #bad_arg = reqparse.Argument(arg)
                errors.append("Unknown argument=%s" % arg)

        if 'dur' not in request.args and 'endtime' not in request.args:
            errors.append("You must specify either 'dur=..' or 'endtime=..' in query!")

        error = None
        error = '\n'.join([e for e in errors])

        args = reqparse.RequestParser.parse_args(self,req)

        return args, error


from obspy import UTCDateTime

def init_query_parser():
    #logger.info("init_query_parser")
    #parser = reqparse.RequestParser()
    parser = StrictParser(bundle_errors=True)

    # FDSN dataselect
    parser.add_argument('net', required=False, help="Network code", location='args')
    parser.add_argument('sta', required=False, help="Station code", location='args')
    parser.add_argument('cha', required=False, help="Channel code", location='args')
    parser.add_argument('loc', required=False, help="Location code", location='args')
    parser.add_argument('start', type=UTCDateTime, required=True,
                        help="Valid start time required, eg, start=2020-11-03T21:13:02.63", location='args')
    #parser.add_argument('start', required=True, help="Start time cannot be blank!")
    # MTH: For USBOR we will temporarily make end optional
    #      Later it should be made required for FDSN dataselect compatibility
    #parser.add_argument('end', required=False, help="End time cannot be blank!")

    # MTH: We *should* be able to define mutually exclusive params as we do in argparse,
    #      but reqparse is pretty lame.  Also, reqparse is scheduled to be removed from
    #      later flask versions.

    # This doesn't work:
    #endparam = parser.add_mutually_exclusive_group(required=True)
    #endparam.add_argument('end', type=UTCDateTime,
                        #help="Valid end time required, eg, end=2020-11-03T21:13:02.63")
    #endparam.add_argument('dur', type=int, help="Duration must be non-zero integer value")

    # Instead, leave it up to user to understand usage!
    parser.add_argument('end', type=UTCDateTime, required=False,
                        help="Valid end time required, eg, end=2020-11-03T21:13:02.63", location='args')

    #parser.add_argument('format', required=False)
    # MTH: sac.zip and geocsv not implemented:
    parser.add_argument('format', required=False, type=str,
                        choices=['png', 'mseed', 'miniseed', 'sac.zip', 'geocsv'], location='args')
    #                   help="Supported formats:{png, miniseed, sac.zip, geocsv}")

    # Additional params:
    parser.add_argument('dur', required=False, type=float, help="Duration must be non-zero float value", location='args')
    parser.add_argument('ptime', type=UTCDateTime, required=False, help="Pick time must be valide UTCDateTime", location='args')
    parser.add_argument('plabel', type=str, required=False, help="Pick label string", location='args')
    parser.add_argument('displayMaxValue', action='store_true', required=False, location='args')
    parser.add_argument('forceReplot', action='store_true', required=False, location='args')
    parser.add_argument('scaleFactor', type=float, required=False, help="scaleFactor must be float > 0.", location='args')
    parser.add_argument('units', type=str, required=False, help="units string - used if --displayMaxValue set", location='args')

    #print(parser.__dict__)

    return parser
